==> haskell-tree-diff-0.0.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.1
id: tree-diff-0.0.1-DHXNqbyOhF1EHCWZeqeXQl
key: tree-diff-0.0.1-DHXNqbyOhF1EHCWZeqeXQl
license: BSD-3-Clause
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data
abi: 44f042f1731406130351e5d772f227f1
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tree-diff-0.0.1
hs-libraries: HStree-diff-0.0.1-DHXNqbyOhF1EHCWZeqeXQl
depends:
    base-4.11.1.0 aeson-1.3.1.1-GWugBGc2PFu9s1ZSj5WAqo
    ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6 bytestring-0.10.8.2
    containers-0.5.11.0 generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    MemoTrie-0.6.9-DH1L4LFeXKx8gvy2yMAor3 parsec-3.1.13.0
    parsers-0.12.8-CMzAOaW0f8m3O3swbOBcI8 pretty-1.1.3.6
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.3.1.1-GWugBGc2PFu9s1ZSj5WAqo=c0ad5c4df215a991062672ba7d02a689
             ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl=9d4f369601ee2b22ce73b0afa89e8002
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             MemoTrie-0.6.9-DH1L4LFeXKx8gvy2yMAor3=058bc7ad5302b6bd94ab4e63f1a949d6
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parsers-0.12.8-CMzAOaW0f8m3O3swbOBcI8=ad58412e4c29842d2bd286be69063782
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tree-diff-0.0.1-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tree-diff.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tree-diff
version: 0.0.1
id: tree-diff-0.0.1-JWbsRI6pVWA6Zm3Gaa4zjl
key: tree-diff-0.0.1-JWbsRI6pVWA6Zm3Gaa4zjl
license: BSD-3-Clause
copyright: (c) 2017 Oleg Grenrus
maintainer: Oleg.Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/tree-diff
synopsis: Diffing of (expression) trees.
description:
    Common diff algorithm works on list structures:
    .
    @
    diff :: Eq a => [a] -> [a] -> [Edit a]
    @
    .
    This package works on trees.
    .
    @
    treeDiff :: Eq a => Tree a -> Tree a -> Edit (EditTree a)
    @
    .
    This package also provides a way to diff arbitrary ADTs,
    using @Generics@-derivable helpers.
    .
    This package differs from <http://hackage.haskell.org/package/gdiff gdiff>,
    in a two ways: @tree-diff@ doesn'\''t have patch function,
    and the "edit-script" is a tree itself, which is useful for pretty-printing.
    .
    @
    >>> prettyEditExpr $ ediff (Foo 42 [True, False] "old") (Foo 42 [False, False, True] "new")
    Foo
    {fooBool = [-True, +False, False, +True],
    fooInt = 42,
    fooString = -"old" +"new"}
    @
category: Data
abi: 44d34e9f18bebae2589150e515e1a5b9
exposed: True
exposed-modules:
    Data.TreeDiff Data.TreeDiff.Class Data.TreeDiff.Expr
    Data.TreeDiff.Golden Data.TreeDiff.List Data.TreeDiff.Parser
    Data.TreeDiff.Pretty Data.TreeDiff.QuickCheck Data.TreeDiff.Tree
import-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tree-diff-0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tree-diff-0.0.1
hs-libraries: HStree-diff-0.0.1-JWbsRI6pVWA6Zm3Gaa4zjl
depends:
    base-4.11.1.0 aeson-1.3.1.1-4Y3ALHMQQEYEDTh2988ctY
    ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1
    base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6 bytestring-0.10.8.2
    containers-0.5.11.0 generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    MemoTrie-0.6.9-DH1L4LFeXKx8gvy2yMAor3 parsec-3.1.13.0
    parsers-0.12.8-CMzAOaW0f8m3O3swbOBcI8 pretty-1.1.3.6
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.3.1.1-4Y3ALHMQQEYEDTh2988ctY=4a6f3fa3d72c8a9dbe85892dfb85eb93
             ansi-wl-pprint-0.6.8.2-6AdIxh22sHDEM4okAgCrQl=9d4f369601ee2b22ce73b0afa89e8002
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=d62b8bf62b1a5e2bfe5d3dedbe6980ab
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             generics-sop-0.3.2.0-5JX38dNigUk7e65oSELmom=69b8ea707aa80039da4ef8d7dea33061
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             MemoTrie-0.6.9-DH1L4LFeXKx8gvy2yMAor3=058bc7ad5302b6bd94ab4e63f1a949d6
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             parsers-0.12.8-CMzAOaW0f8m3O3swbOBcI8=ad58412e4c29842d2bd286be69063782
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             uuid-types-1.0.3-9IxwX10i8f5KLD3aajZO71=073bf76fdf6ac46f8363958226adfe9d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
haddock-interfaces: /usr/share/doc/haskell-tree-diff/html/tree-diff.haddock
haddock-html: /usr/share/doc/haskell-tree-diff/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
